@@ -1,14 +1,15 @@
 package gb
 
 import (
+	"errors"
 	"fmt"
 	"path/filepath"
 	"runtime"
 	"strings"
 	"time"
 
-	"github.com/constabulary/gb/debug"
-	"github.com/constabulary/gb/fileutils"
+	"github.com/constabulary/gb/internal/debug"
+	"github.com/constabulary/gb/internal/fileutils"
 )
 
 // Build builds each of pkgs in succession. If pkg is a command, then the results of build include
@@ -28,7 +29,7 @@ func Build(pkgs ...*Package) error {
 // and any of its dependencies
 func BuildPackages(pkgs ...*Package) (*Action, error) {
 	if len(pkgs) < 1 {
-		return nil, fmt.Errorf("no packages supplied")
+		return nil, errors.New("no packages supplied")
 	}
 
 	targets := make(map[string]*Action) // maps package importpath to build action
