@@ -10,6 +10,8 @@ import (
 	"strconv"
 	"strings"
 	"time"
+
+	"github.com/pkg/errors"
 )
 
 func cgo(pkg *Package) (*Action, []string, []string, error) {
@@ -19,7 +21,7 @@ func cgo(pkg *Package) (*Action, []string, []string, error) {
 	case goversion > 1.4:
 		return cgo15(pkg)
 	default:
-		return nil, nil, nil, fmt.Errorf("unsupported Go version: %v", runtime.Version)
+		return nil, nil, nil, errors.Errorf("unsupported Go version: %v", runtime.Version)
 	}
 }
 
@@ -399,7 +401,7 @@ func runcgo1(pkg *Package, cflags, ldflags []string) error {
 			"-I", pkg.Dir,
 		)
 	default:
-		return fmt.Errorf("unsupported Go version: %v", runtime.Version)
+		return errors.Errorf("unsupported Go version: %v", runtime.Version)
 	}
 	args = append(args, cflags...)
 	args = append(args, pkg.CgoFiles...)
@@ -438,7 +440,7 @@ func runcgo2(pkg *Package, dynout, ofile string) error {
 			"-dynout", dynout,
 		)
 	default:
-		return fmt.Errorf("unsuppored Go version: %v", runtime.Version)
+		return errors.Errorf("unsuppored Go version: %v", runtime.Version)
 	}
 	var buf bytes.Buffer
 	err := runOut(&buf, pkg.Dir, nil, cgo, args...)
