@@ -2,13 +2,14 @@ package main
 
 import (
 	"flag"
-	"fmt"
 	"os"
 	"path/filepath"
 	"runtime"
 
 	"github.com/constabulary/gb"
 	"github.com/constabulary/gb/cmd"
+	"github.com/constabulary/gb/internal/importer"
+	"github.com/pkg/errors"
 )
 
 func init() {
@@ -133,8 +134,6 @@ For more about where packages and binaries are installed, run 'gb help project'.
 
 // Resolver resolves packages.
 type Resolver interface {
-	Projectdir() string
-	// ResolvePackage resolves the import path to a *Package
 	ResolvePackage(path string) (*gb.Package, error)
 }
 
@@ -145,8 +144,15 @@ func resolveRootPackages(r Resolver, paths ...string) ([]*gb.Package, error) {
 	var pkgs []*gb.Package
 	for _, path := range paths {
 		pkg, err := r.ResolvePackage(path)
+		if _, nogo := errors.Cause(err).(*importer.NoGoError); nogo {
+			// if the package is empty, to no Go files are in scope
+			// ignore it.
+			// TODO(dfc) ResolvePackage should return an empty *Package
+			// and build/test should ignore them.
+			continue
+		}
 		if err != nil {
-			return pkgs, fmt.Errorf("failed to resolve import path %q: %v", path, err)
+			return pkgs, errors.Wrapf(err, "failed to resolve import path %q", path)
 		}
 		if pkg.SrcRoot == filepath.Join(runtime.GOROOT(), "src") {
 			// skip package roots that are not part of this project.
