@@ -10,7 +10,8 @@ import (
 
 	"github.com/constabulary/gb"
 	"github.com/constabulary/gb/cmd"
-	"github.com/constabulary/gb/debug"
+	"github.com/constabulary/gb/cmd/gb/internal/match"
+	"github.com/constabulary/gb/internal/debug"
 )
 
 var (
@@ -33,6 +34,7 @@ var commands = make(map[string]*cmd.Command)
 // registerCommand registers a command for main.
 // registerCommand should only be called from init().
 func registerCommand(command *cmd.Command) {
+	setCommandDefaults(command)
 	commands[command.Name] = command
 }
 
@@ -63,6 +65,72 @@ func main() {
 		exit(0)
 	}
 
+	command := lookupCommand(name)
+
+	// add extra flags if necessary
+	command.AddFlags(fs)
+
+	// parse 'em
+	err := command.FlagParse(fs, args)
+	if err != nil {
+		fatalf("could not parse flags: %v", err)
+	}
+
+	// reset args to the leftovers from fs.Parse
+	args = fs.Args()
+
+	// if this is the plugin command, ensure the name of the
+	// plugin is first in the list of arguments.
+	if command == commands["plugin"] {
+		args = append([]string{name}, args...)
+	}
+
+	// if cwd was passed in via -R, make sure it is absolute
+	cwd, err := filepath.Abs(cwd)
+	if err != nil {
+		fatalf("could not make project root absolute: %v", err)
+	}
+
+	// construct a project context at the current working directory.
+	ctx, err := newContext(cwd)
+	if err != nil {
+		fatalf("unable to construct context: %v", err)
+	}
+
+	// unless the command wants to handle its own arguments, process
+	// arguments into import paths.
+	if !command.SkipParseArgs {
+		srcdir := filepath.Join(ctx.Projectdir(), "src")
+		for _, a := range args {
+			// support the "all" build alias. This used to be handled
+			// in match.ImportPaths, but that's too messy, so if "all"
+			// is present in the args, replace it with "..." and set cwd
+			// to srcdir.
+			if a == "all" {
+				args = []string{"..."}
+				cwd = srcdir
+				break
+			}
+		}
+		args = match.ImportPaths(srcdir, cwd, args)
+	}
+
+	debug.Debugf("args: %v", args)
+
+	if destroyContext {
+		atExit = append(atExit, ctx.Destroy)
+	}
+
+	// add additional paths from the depfile
+	addDepfileDeps(ctx)
+
+	if err := command.Run(ctx, args); err != nil {
+		fatalf("command %q failed: %v", name, err)
+	}
+	exit(0)
+}
+
+func lookupCommand(name string) *cmd.Command {
 	command, ok := commands[name]
 	if (command != nil && !command.Runnable()) || !ok {
 		plugin, err := lookupPlugin(name)
@@ -94,35 +162,27 @@ func main() {
 			SkipParseArgs: true,
 		}
 	}
+	setCommandDefaults(command)
+	return command
+}
 
-	// add extra flags if necessary
-	if command.AddFlags != nil {
-		command.AddFlags(fs)
+func setCommandDefaults(command *cmd.Command) {
+
+	// add a dummy default AddFlags field if none provided.
+	if command.AddFlags == nil {
+		command.AddFlags = func(*flag.FlagSet) {}
 	}
 
-	var err error
-	if command.FlagParse != nil {
-		err = command.FlagParse(fs, args)
-	} else {
-		err = fs.Parse(args[2:])
-	}
-	if err != nil {
-		fatalf("could not parse flags: %v", err)
+	// add the default flag parsing if not overrriden.
+	if command.FlagParse == nil {
+		command.FlagParse = func(fs *flag.FlagSet, args []string) error {
+			return fs.Parse(args[2:])
+		}
 	}
+}
 
-	args = fs.Args() // reset args to the leftovers from fs.Parse
-
-	debug.Debugf("args: %v", args)
-
-	if command == commands["plugin"] {
-		args = append([]string{name}, args...)
-	}
-	cwd, err := filepath.Abs(cwd) // if cwd was passed in via -R, make sure it is absolute
-	if err != nil {
-		fatalf("could not make project root absolute: %v", err)
-	}
-
-	ctx, err := cmd.NewContext(
+func newContext(cwd string) (*gb.Context, error) {
+	return cmd.NewContext(
 		cwd, // project root
 		gb.GcToolchain(),
 		gb.Gcflags(gcflags...),
@@ -153,23 +213,4 @@ func main() {
 			return gb.WithRace(c)
 		},
 	)
-
-	if err != nil {
-		fatalf("unable to construct context: %v", err)
-	}
-
-	if !command.SkipParseArgs {
-		args = importPaths(ctx, cwd, args)
-	}
-
-	debug.Debugf("args: %v", args)
-
-	if destroyContext {
-		atExit = append(atExit, ctx.Destroy)
-	}
-
-	if err := command.Run(ctx, args); err != nil {
-		fatalf("command %q failed: %v", name, err)
-	}
-	exit(0)
 }
